@@ -2,6 +2,9 @@ package EventStore::Tiny::Event;
 
 use strict;
 use warnings;
+use feature 'signatures';
+no warnings 'experimental::signatures';
+use Carp;
 
 use UUID::Tiny qw(create_uuid_as_string);
 use Time::HiRes qw(time);
@@ -9,13 +12,12 @@ use Time::HiRes qw(time);
 use Class::Tiny {
     uuid        => sub {create_uuid_as_string},
     timestamp   => sub {time},
-    name        => sub {die "name is required.\n"},
-    trans_store => sub {die "trans_store is required."},
+    name        => sub {croak "name is required.\n"},
+    trans_store => sub {croak "trans_store is required."},
     data        => sub {{}},
 };
 
-sub BUILD {
-    my $self = shift;
+sub BUILD ($self, @) { # @ is neccessary for Class::Tiny
 
     # Set/Test non-lazy
     $self->name;
@@ -26,17 +28,15 @@ sub BUILD {
     return;
 }
 
-sub transformation {
-    my $self = shift;
+sub transformation ($self) {
     my $name = $self->name;
     my $t    = $self->trans_store->get($name);
-    die "Transformation for $name not found!\n" unless defined $t;
+    croak "Transformation for $name not found!\n" unless defined $t;
     return $t;
 }
 
 # Lets transformation work on state by side-effect
-sub apply_to {
-    my ($self, $state, $logger) = @_;
+sub apply_to ($self, $state, $logger = undef) {
 
     # Apply the transformation by side effect
     $self->transformation->($state, $self->data);
@@ -49,8 +49,7 @@ sub apply_to {
 }
 
 # Return a one-line summary of this event
-sub summary {
-    my $self = shift;
+sub summary ($self) {
 
     # Prepare date and time
     my $decimals    = $self->timestamp =~ /(\.\d+)$/ ? $1 : '';
@@ -160,7 +159,7 @@ L<EventStore::Tiny>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2018 Mirko Westermeier (mail: mirko@westermeier.de)
+Copyright (c) 2018-2021 Mirko Westermeier (mail: mirko@westermeier.de)
 
 Released under the MIT License (see LICENSE.txt for details).
 
